import React, { HTMLProps, useState } from "react";
import { useFormik } from "formik";
import { Nullable } from "../helpers";
import { formatAddress, Company, emptyCompany, BranchOffice } from "../data/company";
import { sampleCompanies } from "../provider/company";
import { Autocomplete } from "@material-ui/lab";
import { Box, Grid, TextField, Typography } from "@material-ui/core";

export type CompanyFormProps = {

}

export const CompanyItem = ({ company, ...props }: { company: Company } & HTMLProps<any>) => (
    <div className="company-item" {...props}>
        <div>{ company.name }</div>
        <Typography variant="caption">NIP: <strong>{ company.nip }</strong></Typography>
    </div>
)

export const OfficeItem = ({ office, ...props }: { office: BranchOffice } & HTMLProps<any>) => (
    <div className="office-item" {...props}>
        <div>{ office.address.city }, { office.address.street }</div>
        <Typography variant="caption">{ formatAddress(office.address) }</Typography>
    </div>
)

export const CompanyForm: React.FunctionComponent<CompanyFormProps> = props => {
    const formik = useFormik<Nullable<Company>>({ onSubmit: values => console.log(values), initialValues: emptyCompany });

    const formikProps = (prop: keyof Company) => ({ onChange: formik.handleChange, value: formik.values[prop], name: prop })

    const [company, setCompany] = useState<Company | null>(null);

    return (
        <Grid container spacing={3}>
            <Grid item xs={12}>
                <Autocomplete options={ sampleCompanies }
                              getOptionLabel={ option => option.name }
                              renderOption={ company => <CompanyItem company={company} /> }
                              renderInput={ props => <TextField {...props} label={"Nazwa firmy"} fullWidth />}
                              onChange={ (ev, value: Company | null) => {
                                  setCompany(value)

                                  formik.setFieldValue("name", value?.name || "")
                                  formik.setFieldValue("url", value?.url || "");
                                  formik.setFieldValue("nip", value?.nip || "");
                              } }
                />
            </Grid>
            <Grid container item spacing={2} xs={12}>
                <Grid item xs={4}>
                    <TextField label={"NIP"} fullWidth {...formikProps("nip")} disabled={ company != null}/>
                </Grid>
                <Grid item xs={8}>
                    <TextField label={"Url"} fullWidth {...formikProps("url")} disabled={ company != null }/>
                </Grid>
            </Grid>
            <Grid item xs={12}>
                <Autocomplete options={ company?.offices || [] }
                              disabled={ company == null}
                              getOptionLabel={ office => office.address.city }
                              renderOption={ office => <OfficeItem office={ office } /> }
                              renderInput={ props => <TextField {...props} label={"Oddział"} fullWidth />}
                />
            </Grid>
        </Grid>
    )
}

